(sec_citation)=
# Citing DemesDraw

If you use DemesDraw in your work, please cite the
[Demes paper](https://doi.org/10.1093/genetics/iyac131).

```bibtex
@article{gower_demes_2022,
  title        = {Demes: a standard format for demographic models},
  url          = {https://doi.org/10.1093/genetics/iyac131},
  doi          = {10.1093/genetics/iyac131},
  journal      = {Genetics},
  author       = {Gower, Graham and Ragsdale, Aaron P and Bisschop,
    Gertjan and Gutenkunst, Ryan N and Hartfield, Matthew and Noskova,
    Ekaterina and Schiffels, Stephan and Struck, Travis J and
    Kelleher, Jerome and Thornton, Kevin R},
  month        = sep,
  year         = 2022,
  pages        = {iyac131},
}
```

If you wish to refer to DemesDraw specifically rather than just Demes,
please adapt the following bibtex entry as appropriate for citing software
for your publication.

```bibtex
@misc{gower_demesdraw_2022,
  title = {DemesDraw: Drawing functions for {Demes} demographic models},
  howpublished = {https://github.com/grahamgower/demesdraw},
  author = {Gower, Graham},
  version = {0.4.1},
  year = 2022,
}
```
